==> wow_views-0.0.8.tar.gz: lib/compoment/view/ButtonDangKy.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wow_views/compoment/iAction.dart';
import 'package:wowit/message.dart';
import 'package:wowit/methods.dart';

class ButtonDangKy {
  Widget getMainView(Map<String, dynamic> data,String tableName) {
    var dataReponse = Methods.getList(data['data'], tableName);
    IActionEvent iAction = data['ActionEvent'] as IActionEvent;
    List<Map<String,Object>> dsAction = data['dsAction'];
    return Container(
      width: Get.width,
      alignment: Alignment.center,
      child: Container(
        padding: const EdgeInsets.symmetric(vertical: 8),
        width: Get.width / 2,
        child: ElevatedButton(
          style: ButtonStyle(
            backgroundColor: MaterialStateProperty.resolveWith<Color>((state) {
              return  const Color(0xFFF79750);
            }),
            padding: MaterialStateProperty.all<EdgeInsets>(
                const EdgeInsets.symmetric(horizontal: 16, vertical: 8)),
            shape: MaterialStateProperty.all<OutlinedBorder>(
              RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(10),
              ),
            ),
            minimumSize: MaterialStateProperty.all<Size>(const Size(0, 0)),
            tapTargetSize: MaterialTapTargetSize.shrinkWrap,
          ),
          onPressed: () {
            int id = 0;
            if (dataReponse.isNotEmpty) {
              id = Methods.getInt(dataReponse[0], 'ID');
            }
            iAction.actionCompoment(4,dsAction,idData: id);
          },
          child: Text(Message.getMessage('BUTTON_DANG_KY'),style:const TextStyle(
            color: Colors.white,
            fontWeight: FontWeight.bold,
            fontSize: 16,
          ),),
        ),
      ),
    );
  }
}

==> wow_views-0.0.9.tar.gz: lib/compoment/view/ButtonDangKy.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wow_views/compoment/iAction.dart';
import 'package:wowit/message.dart';
import 'package:wowit/methods.dart';

class ButtonDangKy {
  Widget getMainView(Map<String, dynamic> data,String tableName) {
    var dataReponse = Methods.getList(data['data'], tableName);
    IActionEvent iAction = data['ActionEvent'] as IActionEvent;
    List<Map<String,Object>> dsAction = data['dsAction'];
    return Container(
      width: Get.width,
      alignment: Alignment.center,
      child: Container(
        padding: const EdgeInsets.symmetric(vertical: 8),
        width: Get.width / 2,
        child: ElevatedButton(
          style: ButtonStyle(
            backgroundColor: MaterialStateProperty.resolveWith<Color>((state) {
              return  const Color(0xFFF79750);
            }),
            padding: MaterialStateProperty.all<EdgeInsets>(
                const EdgeInsets.symmetric(horizontal: 16, vertical: 8)),
            shape: MaterialStateProperty.all<OutlinedBorder>(
              RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(10),
              ),
            ),
            minimumSize: MaterialStateProperty.all<Size>(const Size(0, 0)),
            tapTargetSize: MaterialTapTargetSize.shrinkWrap,
          ),
          onPressed: () {
            int id = 0;
            if (dataReponse.isNotEmpty) {
              id = Methods.getInt(dataReponse[0], 'ID',defaultValue: null);
            }
            iAction.actionCompoment(4,dsAction,idData: id);
          },
          child: Text(Message.getMessage('BUTTON_DANG_KY'),style:const TextStyle(
            color: Colors.white,
            fontWeight: FontWeight.bold,
            fontSize: 16,
          ),),
        ),
      ),
    );
  }
}
